//******************************************************************************************************************
// Authentication.ino - part of talking_dtmf_relay.ino
// handles 3 digit password authentication.
//******************************************************************************************************************

void authenticate(byte DTMFdata)
{
  int i = 0;
  if(authenticated == false)
  {
      if(currentMillis > previousMillis + keyWaitInterval && passKeyPointer > 0){
        previousMillis = millis();
        passKeyPointer = 0;
        return;
      }
      if(passKeyPointer == 0){                      //ask for password
        delay(1500);
        digitalWrite(pttRelayPin, HIGH);
        delay(500);
        voice.say(spENTER);
        voice.say(spSECURITY);
        voice.say(spPASS);
        digitalWrite(pttRelayPin, LOW);
        passKeyPointer = 1;
        previousMillis = millis();
        return;
      }
      if(passKeyPointer < 4){                       //store digit
        passKeys[passKeyPointer] = DTMFdata;
        passKeyPointer = passKeyPointer + 1;
        previousMillis = millis();
        if(passKeyPointer != 4){
          return;
        }
      }

      authenticated = true;                         //set to true then test each element
      for(i = 1; i < 4; i++){
        if(passKeys[i] != password[i]){
          authenticated = false;
          delay(1500);
          digitalWrite(pttRelayPin, HIGH);
          delay(500);
          voice.say(spNEGATIVE);
          digitalWrite(pttRelayPin, LOW);
          previousMillis = millis();
          passKeyPointer = 0;
          return;
        }
      }
      delay(1500);
      digitalWrite(pttRelayPin, HIGH);
      delay(500);
      voice.say(spREADY);
      digitalWrite(pttRelayPin, LOW);
      previousAuthenticationMillis = millis();    //get time of authentication
      return;
  }
  
  //we are authenticated, check if authentication time has expired
  if(currentMillis > previousAuthenticationMillis + authenticationInterval){
    authenticated = false;
    delay(1500);
    digitalWrite(pttRelayPin, HIGH);
    delay(500);
    voice.say(spTIME);
    voice.say(spOUT);
    delay(500);
    voice.say(spENTER);
    voice.say(spSECURITY);
    voice.say(spPASS);
    digitalWrite(pttRelayPin, LOW);
    passKeyPointer = 1;
    previousMillis = millis();
    return;
  }
  
  previousAuthenticationMillis = millis();    //reset time of authentication
  return;
}
